/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: $ */
/**
 * FontFinder for native Mac flavoured platforms
 */
package org.apache.fop.fonts.autodetect;

/**
 * Mac font directory finder
 * 
 * @author Adrian Cumiskey
 */
class MacFontDirFinder extends NativeFontDirFinder {

    /*
     * @see org.apache.fop.fonts.autodetect.NativeFontDirFinder#getFontDirList()
     */
    protected FontDirInfo[] getFontDirInfo() {
        /**
         * standard mac font directory locations
         */
        return new FontDirInfo[] {
                new FontDirInfo(
                        System.getProperty("user.home") + "/Library/Fonts/",
                        true), // user
                new FontDirInfo("/Library/Fonts/", RECURSE), // local
                new FontDirInfo("/System/Library/Fonts/", RECURSE), // system
                new FontDirInfo("/Network/Library/Fonts/", RECURSE), // network

        /**
         * Andreas Delmelle notes: The latest available JVM for classic platform
         * was 1.2, IIRC, so if we consider 1.4 as minimal target JVM for the
         * next release, FOP wouldn't run on it anyway.
         */
        // new FontDirInfo("/System Folder/Fonts/") // classic
        };
    }
}
