/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: $ */
package org.apache.fop.fonts.autodetect;

import java.io.File;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.fop.util.FileUtil;

/**
 * Native font finder base class
 *
 * @author Adrian Cumiskey
 */
public abstract class NativeFontDirFinder implements FontFinder {

    /** logging instance */
    static final Log log = LogFactory.getLog(FontFinder.class);
    static final boolean RECURSE = true;
    static final boolean DONT_RECURSE = false;
    
    /**
     * Default constructor
     */
    public NativeFontDirFinder() {
    }
    
    /**
     * Generic method used by Mac and Unix font finders
     * @see FontFinder#find()
     */
    public List find() {
        List fontDirList = new java.util.ArrayList();
        FontDirInfo[] fontDirInfo = getFontDirInfo();
        if (fontDirInfo != null) {
            for (int i = 0; i < fontDirInfo.length; i++) {
                FontDirInfo fontDir = fontDirInfo[i];
                if (FileUtil.validDirectory(fontDir.getFile())) {                
                    fontDirList.add(fontDir);
                }
            }
        }
        return fontDirList;
    }
    
    /**
     * 
     * Represents a font directory that we may wish to search
     * 
     * @author Adrian Cumiskey
     *
     */
    static protected class FontDirInfo {
        /**
         * File encapsulation of directory path
         */
        private File dir;

        /**
         * should be recursively searched?
         */
        private boolean recurse = false;

        /**
         * Default constructor
         * 
         * @param path font directory path
         */
        public FontDirInfo(String path) {
            this.dir = new File(path);
        }

        /**
         * Constructor
         * 
         * @param path font directory path
         * @param recurse recurse or not
         */
        public FontDirInfo(String path, boolean recurse) {
            this(path);
            this.recurse = recurse;
        }

        /**
         * File representaiton of this font directory
         * @return
         */
        public File getFile() {
            return this.dir;
        }

        /**
         * Whether this font directory should be searched recursively
         * @return
         */
        public boolean isRecursive() {
            return this.recurse;
        }
    }

    /**
     * native font directory paths 
     * @return array of FontDir objects
     */
    protected FontDirInfo[] getFontDirInfo() {
        return null;
    }
}
