/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: $ */
package org.apache.fop.fonts.autodetect;

import java.util.List;

import org.apache.fop.apps.FOPException;
import org.apache.fop.fonts.FontResolver;
import org.apache.fop.fonts.autodetect.NativeFontDirFinder.FontDirInfo;


/*
 * Font Finder Factory
 *
 * @author Adrian Cumiskey
 */
public class NativeFontFileFinder {
    
    /** native font finder implementation */
    private static FontFinder fontDirFinder = null;
    
    private static FontFinder getFontDirFinder() {
        if (fontDirFinder == null) {
            final String OS_NAME = System.getProperty("os.name");
            if (OS_NAME.startsWith("Windows")) {
                fontDirFinder = new WindowsFontDirFinder();
            } else {
                if (OS_NAME.startsWith("Mac")) {
                    fontDirFinder = new MacFontDirFinder();
                } else {
                    fontDirFinder = new UnixFontDirFinder();
                }
            }
        }
        return fontDirFinder;
    };
    
    /**
     * Finds/identifies font files within a given directory.
     * 
     * @param fontResolver font resolver used to resolve font
     * @param strict validate configuration strictly
     * @return list of found font files
     * @throws FOPException if something's wrong with the config data
     */
    public static List find(FontResolver fontResolver, boolean strict)
    throws FOPException {
        List fontFileList = new java.util.ArrayList();
        List fontDirList = getFontDirFinder().find();
        for (int i = 0; i < fontDirList.size(); i++) {
            FontDirInfo fontDir = (FontDirInfo)fontDirList.get(i);
            List fontFiles = FontFileFinder.find(
                    fontDir.getFile(), fontResolver, fontDir.isRecursive(), strict);
            fontFileList.addAll(fontFiles);
        }
        return fontFileList;
    }
}
